==> was-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/was/step/create-webspherecluster-51.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

# Simple WSADmin/Jython script to create a vhost in WAS 5.1
# Checks whether cluster with passed argument already exists.
# If true, then does nothing else creates a new cluster
# Usage: wsadmin -f create-webspherecluster-51.py <cellname> <clustername>

import sys

cellname = sys.argv[0];
clustername = sys.argv[1];

clusterId = AdminConfig.getid('/ServerCluster:'+clustername+'/');

if clusterId == "" :
        print "Deployit INFO: Creating ServerCluster : "+clustername

        cell = AdminConfig.getid('/Cell:' + cellname + '/');
        AdminConfig.create('ServerCluster', cell, [['name', clustername]]);
        AdminConfig.save();

        print "Deployit INFO: Created ServerCluster : "+clustername
else :
        print "Deployit INFO: ServerCluster : "+clustername+ " already exists."

==> was-plugin-1.3.jar: com/xebialabs/deployit/plugin/was/step/create-webspherecluster-51.py <==
#
# Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

# Simple WSADmin/Jython script to create a vhost in WAS 5.1
# Checks whether cluster with passed argument already exists.
# If true, then does nothing else creates a new cluster
# Usage: wsadmin -f create-webspherecluster-51.py <cellname> <clustername>

import sys

cellname = sys.argv[0];
clustername = sys.argv[1];

clusterId = AdminConfig.getid('/ServerCluster:'+clustername+'/');

if clusterId != "":
    print "Cluster " + clustername + " already exists. Doing nothing."
    sys.exit(0)

print "Creating cluster " + clustername
cell = AdminConfig.getid('/Cell:' + cellname + '/');
AdminConfig.create('ServerCluster', cell, [['name', clustername]]);

print "Saving configuration"
AdminConfig.save();
